@@ -9,24 +9,50 @@ log = logging.getLogger(__name__)
 
 class OAuth2ClientCredentialsSession(requests.Session):
     """
-    Wrapper around requests.Session that receives authentication tokens through
-    'client_credentials' type of OAuth2 grant, and adds tokens to the requests made through the session,
-    as well as attempts to keep track of the token and refresh it when the time comes.
+    Wrapper around `requests.Session <https://docs.python-requests.org/en/latest/api/#requests.Session>`_
+    which receives authentication tokens through the ``client_credentials`` type of OAuth2 grant,
+    and adds tokens to the requests made through the session.
+    It also attempts to keep track of the token and refresh it as needed.
 
-    If proxies are defined, every request will use them.
-    This session doesn't requests authorization from the user first, the scope should be pre-authorized.
+    * If proxies are defined, every request will use them.
 
-    Usage:
-    >>> api1 = OAuth2ClientCredentialsSession('https://example1.com/<tenant_id>/oauth/v2/',\
-                        client_id='xxx', client_secret='xxx')
-    >>> api2 = OAuth2ClientCredentialsSession('https://example2.com/<tenant_id>/oauth/v2/',\
-                        client_id='xxx', client_secret='xxx')
-    >>>
-    >>> api1.post('https://example1.com/v4/me/messages', data={}) # use as a regular requests session object
-    >>> api2.get('https://example2.com/v2/me/updates')
-    >>> # When writing an integration, use RequestsCommon to get the proxies defined in in your app.config file.
-    >>> rc = RequestsCommon(xxx)
-    >>> api3 = OAuth2ClientCredentialsSession('https://example3.com/{}/test', proxies=rc.get_proxies())
+    This session does not request authorization from the user first. The scope should be pre-authorized.
+
+    **Example:**
+
+    .. code-block:: python
+
+        from resilient_lib import OAuth2ClientCredentialsSession, RequestsCommon
+
+        api1 = OAuth2ClientCredentialsSession('https://example1.com/<tenant_id>/oauth/v2/', client_id='xxx', client_secret='xxx')
+        api2 = OAuth2ClientCredentialsSession('https://example2.com/<tenant_id>/oauth/v2/', client_id='xxx', client_secret='xxx')
+
+        api1.post('https://example1.com/v4/me/messages', data={}) # use as a regular requests session object
+
+        api2.get('https://example2.com/v2/me/updates')
+
+        # When writing an integration, use RequestsCommon to get the proxies defined in in your app.config file.
+        rc = RequestsCommon(opts, function_opts)
+        api3 = OAuth2ClientCredentialsSession('https://example3.com/{}/test', proxies=rc.get_proxies())
+
+    :param url: Authorization URL, with tenant_id in it, if required
+    :type url: str
+    :param client_id: API key/User ID
+    :type client_id: str
+    :param client_secret: secret for API key
+    :type client_secret: str
+    :param scope: (optional) list of scopes
+    :type scope: [str]
+    :param proxies: (optional) Dictionary mapping protocol to the URL of the proxy.
+            The mapping protocol must be in the format:
+
+            .. code-block::
+
+                {
+                    "https_proxy": "https://localhost:8080,
+                    "http_proxy": "http://localhost:8080
+                }
+    :type proxies: dict
     """
 
     AUTHORIZATION_ERROR_CODES = [401, 403]
@@ -34,11 +60,6 @@ class OAuth2ClientCredentialsSession(requests.Session):
     def __init__(self, url=None, client_id=None, client_secret=None, scope=None, proxies=None):
         """
         Get OAuth2 tokens and save them to be used in session requests.
-        :param url: authorization url, with tenant_id in it, if required
-        :param client_id: API key/User Id
-        :param client_secret: secret for API
-        :param scope: optional, list of scopes
-        :param proxies: Dict - proxies to make the requests through
         """
         # __init__ is run even if __new__ returned existing instance
         if getattr(self, "authorization_url", None) is not None:
@@ -73,12 +94,7 @@ class OAuth2ClientCredentialsSession(requests.Session):
 
     def authenticate(self, url, client_id, client_secret, scope, proxies=None):
         """
-        :param url: String - authorization url - end point for authentication
-        :param client_id: String
-        :param client_secret: String
-        :param scope: list<String> - list of scopes the token should provide access to
-        :param proxies: object with proxy data
-        :return: True/False - was/wasn't able to authenticate.
+        Authenticate with the endpoint
         """
         token_url = url
 
@@ -102,24 +118,55 @@ class OAuth2ClientCredentialsSession(requests.Session):
 
         return True
 
-
     def get_token(self, token_url, client_id, client_secret, scope=None, proxies=None):
         """
-        Override this method if there are any specific things that need to be changed.
-        Such as Cloud Foundry asking grant_type to be 'password' and API key to be passed in 'password'.
+        **Override this method if the request needs specific information in the
+        body of the request**
+
+        For example, *Cloud Foundry* asking ``grant_type`` to be ``password`` and API key to be passed in ``password``.
+
+        The default is:
+
+        .. code-block:: python
+
+            post_data = {
+                'client_id': client_id,
+                'client_secret': client_secret,
+                'grant_type': 'client_credentials'
+            }
+
+            if scope:
+                post_data['scope'] = scope
+
+        :param token_url: Authorization URL, with tenant_id in it, if required
+        :type token_url: str
+        :param client_id: API key/User ID
+        :type client_id: str
+        :param client_secret: secret for API key
+        :type client_secret: str
+        :param scope: (optional) list of scopes
+        :type scope: [str]
+        :param proxies: (optional) Dictionary mapping protocol to the URL of the proxy.
+        :type proxies: dict
+        :return: the ``response`` from the ``token_url``
+        :rtype: `requests.Response <https://docs.python-requests.org/en/latest/api/#requests.Response>`_
         """
         post_data = {
             'client_id': client_id,
             'client_secret': client_secret,
             'grant_type': 'client_credentials'
         }
-        if scope is not None:
+        if scope:
             post_data['scope'] = scope
         return self.post(token_url, data=post_data, proxies=proxies)
 
     def update_token(self):
         """
         Institutes a request for a new access token.
+
+        :raises ValueError: If it cannot update the token
+        :return: True if could get a new token
+        :rtype: bool
         """
         try:
             self.authenticate(self.authorization_url, self.client_id,
@@ -130,9 +177,16 @@ class OAuth2ClientCredentialsSession(requests.Session):
         return True
 
     def request(self, method, url, *args, **kwargs):
-        """Constructs a :class:`Request <Request>`, injects it with tokens, sends it
-        in a new session to avoid having one session constantly open.
-        Returns :class:`Response <Response>` object.
+        """Constructs a `requests.Request <https://docs.python-requests.org/en/latest/api/#requests.Request>`_,
+        injects it with tokens and sends it in a new session to avoid having one session constantly open.
+
+        This uses the ``requests.request()`` function to
+        make a call. The inputs are mapped to this function.
+        See `requests.request() <https://docs.python-requests.org/en/latest/api/#requests.request>`_
+        for information on any parameters available
+
+        :return: the ``response`` object
+        :rtype: `requests.Response <https://docs.python-requests.org/en/latest/api/#requests.Response>`_
         """
 
         # Don't check expiration if attempting to refresh authorization - would cause infinite recursion loop
@@ -158,5 +212,8 @@ class OAuth2ClientCredentialsSession(requests.Session):
     def add_authorization_header(self, headers):
         """
         Create headers needed for authentication/authorization, overriding the default ones if needed.
+
+        :param headers: Dictionary containing the ``Authorization`` header
+        :type headers: dict
         """
         headers["Authorization"] = "{} {}".format(self.token_type, self.access_token)
