@@ -11,6 +11,7 @@ import sys
 import tempfile
 
 import resilient
+import sys
 from bs4 import BeautifulSoup
 from cachetools import TTLCache, cached
 from six import string_types
@@ -25,7 +26,7 @@ LOG.addHandler(logging.StreamHandler())
 
 def build_incident_url(url, incidentId):
     """
-    Build the url to link to a SOAR incident
+    Build the URL to link to a SOAR incident
 
     :param url: the URL of your SOAR instance
     :type url: str
@@ -39,7 +40,7 @@ def build_incident_url(url, incidentId):
 
 def build_resilient_url(host, port):
     """
-    Build basic url to resilient instance
+    Build basic URL to SOAR instance
 
     :param host: host name
     :type host: str
@@ -56,8 +57,8 @@ def build_resilient_url(host, port):
 
 def clean_html(html_fragment):
     """
-    Resilient textarea fields return html fragments. This routine will remove the
-    html and insert any code within ``<div></div>`` with a linefeed
+    SOAR textarea fields return HTML fragments. This routine removes the
+    HTML and inserts any code within ``<div></div>`` with a linefeed.
 
     .. note::
         The string returned from this method may not format well as no presentation of line feeds are preserved,
@@ -101,7 +102,6 @@ def unescape(data):
     else:
         # In PY 3, unescape is in html library
         import html
-
         return html.unescape(data)
 
 
@@ -114,8 +114,8 @@ def validate_fields(field_list, kwargs):
     a field name or it can be a list/tuple of ``dicts`` where each item
     has the attributes ``name`` (**required**) and ``placeholder`` (**optional**).
 
-    ``kwargs`` can be a dict/namedtuple. If it is a namedtuple tries to call it's
-    ``kwargs._as_dict()`` method and raises a ``ValueError`` if it cannot.
+    ``kwargs`` can be a dict or namedtuple. If a namedtuple, it calls its
+    ``kwargs._as_dict()`` method and raises a ``ValueError`` if it does not succeed.
 
     * If the value of the item in ``kwargs`` is equal to its ``placeholder``
       defined in ``field_list``, a ``ValueError`` is raised.
@@ -201,7 +201,7 @@ def validate_fields(field_list, kwargs):
 
 def get_file_attachment(res_client, incident_id, artifact_id=None, task_id=None, attachment_id=None):
     """
-    Call the Resilient REST API to get the attachment or artifact data for
+    Call the SOAR REST API to get the attachment or artifact data for
     an Incident or a Task
 
     * If ``incident_id`` and ``artifact_id`` are defined it will get that Artifact
@@ -221,7 +221,7 @@ def get_file_attachment(res_client, incident_id, artifact_id=None, task_id=None,
         with open("malware.eml", "wb") as f:
             f.write(artifact_data)
 
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :type res_client: resilient_circuits.ResilientComponent.rest_client()
     :param incident_id: id of the Incident
     :type incident_id: int|str
@@ -253,9 +253,9 @@ def get_file_attachment(res_client, incident_id, artifact_id=None, task_id=None,
 
 def get_file_attachment_metadata(res_client, incident_id, artifact_id=None, task_id=None, attachment_id=None):
     """
-    Call the Resilient REST API to get the attachment or artifact attachment metadata
+    Call the SOAR REST API to get the attachment or artifact attachment metadata
 
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :type res_client: resilient_circuits.ResilientComponent.rest_client()
     :param incident_id: id of the Incident
     :type incident_id: int|str
@@ -288,9 +288,9 @@ def get_file_attachment_metadata(res_client, incident_id, artifact_id=None, task
 
 def get_file_attachment_name(res_client, incident_id=None, artifact_id=None, task_id=None, attachment_id=None):
     """
-    Call the Resilient REST API to get the attachment or artifact attachment name
+    Call the SOAR REST API to get the attachment or artifact attachment name
 
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :type res_client: resilient_circuits.ResilientComponent.rest_client()
     :param incident_id: id of the Incident
     :type incident_id: int|str
@@ -324,7 +324,7 @@ def get_file_attachment_name(res_client, incident_id=None, artifact_id=None, tas
 
 def write_file_attachment(res_client, file_name, datastream, incident_id, task_id=None, content_type=None):
     """
-    Add a file attachment to Resilient using the REST API
+    Add a file attachment to SOAR using the REST API
     to an Incident or a Task
 
     **Example:**
@@ -334,7 +334,7 @@ def write_file_attachment(res_client, file_name, datastream, incident_id, task_i
         with open("malware.eml", "rb") as data_stream:
             res = write_file_attachment(self.rest_client(), "malware.eml", data_stream, 2001)
 
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :type res_client: :class:`ResilientComponent.rest_client() <resilient_circuits.actions_component.ResilientComponent.rest_client()>`
     :param file_name: name of the attachment to create
     :type file_name: str
@@ -354,31 +354,23 @@ def write_file_attachment(res_client, file_name, datastream, incident_id, task_i
                    or mimetypes.guess_type(file_name or "")[0] \
                    or "application/octet-stream"
 
-    attachment = datastream.read()
-
     """
-    Writing to temp path so that the REST API client can use this file path 
+    Writing to temp path so that the REST API client can use this file path
     to read and POST the attachment
     """
 
-    with tempfile.NamedTemporaryFile(delete=False) as temp_file:
-        try:
-            temp_file.write(attachment)
-            temp_file.close()
+    # Create a new attachment by calling SOAR REST API
 
-            # Create a new attachment by calling resilient REST API
+    if task_id:
+        attachment_uri = "/tasks/{}/attachments".format(task_id)
+    else:
+        attachment_uri = "/incidents/{}/attachments".format(incident_id)
 
-            if task_id:
-                attachment_uri = "/tasks/{}/attachments".format(task_id)
-            else:
-                attachment_uri = "/incidents/{}/attachments".format(incident_id)
-
-            new_attachment = res_client.post_attachment(attachment_uri,
-                                                        temp_file.name,
-                                                        filename=file_name,
-                                                        mimetype=content_type)
-        finally:
-            os.unlink(temp_file.name)
+    new_attachment = res_client.post_attachment(attachment_uri,
+                                                None,
+                                                filename=file_name,
+                                                mimetype=content_type,
+                                                bytes_handle=datastream)
 
     if isinstance(new_attachment, list):
         new_attachment = new_attachment[0]
@@ -390,7 +382,7 @@ def readable_datetime(timestamp, milliseconds=True, rtn_format='%Y-%m-%dT%H:%M:%
     """
     Convert an epoch timestamp to a string using a format
 
-    :param timestamp: ts of object sent from Resilient Server i.e. ``incident.create_date``
+    :param timestamp: ts of object sent from SOAR Server i.e. ``incident.create_date``
     :type timestamp: int
     :param milliseconds: Set to ``True`` if ts in milliseconds
     :type milliseconds: bool
@@ -504,7 +496,7 @@ def close_incident(res_client, incident_id, kwargs, handle_names=False):
             handle_names=True
         )
 
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :type res_client: resilient_circuits.ResilientComponent.rest_client()
     :param incident_id: id of the incident
     :type incident_id: int|str
@@ -531,7 +523,7 @@ def close_incident(res_client, incident_id, kwargs, handle_names=False):
     if "plan_status" not in mandatory_fields:
         mandatory_fields["plan_status"] = "C"
 
-    # API call to the Resilient REST API to patch the incident data (close incident)
+    # API call to the SOAR REST API to patch the incident data (close incident)
     response = _patch_to_close_incident(res_client, incident_id, mandatory_fields, handle_names)
 
     return response
@@ -539,7 +531,7 @@ def close_incident(res_client, incident_id, kwargs, handle_names=False):
 
 def _get_required_fields(res_client):
     """
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :return: list
     """
     fields = _get_incident_fields(res_client)
@@ -551,9 +543,9 @@ def _get_required_fields(res_client):
 @cached(cache=TTLCache(maxsize=10, ttl=600))
 def _get_incident_fields(res_client):
     """
-    call the Resilient REST API to get list of fields required to close an incident
+    call the SOAR REST API to get list of fields required to close an incident
     this call is cached for multiple calls
-    :param res_client: required for communication back to resilient
+    :param res_client: required for communication back to SOAR
     :return: json
     """
     uri = "/types/incident"
@@ -565,8 +557,8 @@ def _get_incident_fields(res_client):
 
 def _patch_to_close_incident(res_client, incident_id, close_fields, handle_names=False):
     """
-    call the Resilient REST API to patch incident
-    :param res_client: required for communication back to resilient
+    call the SOAR REST API to patch incident
+    :param res_client: required for communication back to SOAR
     :param incident_id: required
     :param close_fields: required
     :return: response object
